# GWCelery Helm Chart

This repository contains the Helm charts to deploy GWCelery and Redis on a Kubernetes cluster. Default values allow for a sandboxed deployment on Minikube.

The package registry of this project can be used as Helm repository:
```
helm repo add --username <username> --password <token> gwcelery-helm \ 
    https://git.ligo.org/api/v4/projects/16068/packages/helm/stable
```

Where:
- `username` is your _albert.einstein_ username
- `token` is a _read_api_ scoped personal access token

After adding the Helm repository with the command above, the charts can be installed in the _default_ namespace in this way:
```
helm install gwcelery gwcelery-helm/gwcelery
```

## Configuration

| Key | Description | Type | Required | Default |
|---|---|---|---|---|
| `gwcelery.celeryConfig` | Contents of the GWCelery configuration file to be used as helm-k8s. If not specified, the specified celeryConfigModule is used. | string | false |  |
| `gwcelery.celeryConfigModule` | The configuration to be used.  If celeryConfig is set, gwcelery.conf.helm-k8s will be used | string | true | gwcelery.conf.minikube |
| `gwcelery.hostAlias.hostname` | Additional host for the /etc/hosts file inside the Pods. | string | false |  |
| `gwcelery.hostAlias.ip` | Additional ip for the _/etc/hosts_ file inside the Pods. | string | false |  |
| `gwcelery.gracedb.caSecret` | Name of the Secret containing the CA certificate corresponding to the GraceDB self-signed server certificate. | string | false | gracedb-ca |
| `gwcelery.gracedb.hostname` | Routable name of the GraceDB instance. | string | true | gracedb.default.svc.cluster.local |
| `gwcelery.igwnHostname` | Endpoint of the IGWN-alert server (SCIMMA Hopskotch). | string | true | kafka://hopskotch.default.svc.cluster.local |
| `gwcelery.kafkaHostname` | Kafka endpoint for public alerts. | string | true | kafka://hopskotch.default.svc.cluster.local |
| `gwcelery.image.repository` | Repository for the application image. | string | true | containers.ligo.org/emfollow/gwcelery |
| `gwcelery.image.tag` | Tag of the image to be used. | string | true | v2.6.0 |
| `gwcelery.image.pullPolicy` | Image pull policy. | string | true | IfNotPresent |
| `gwcelery.probes.readiness.delay` | Delay in seconds before initiating the readiness probe. | integer | true | 60 |
| `gwcelery.probes.readiness.timeout` | Timeout in seconds for the readiness probe. | integer | true | 30 |
| `gwcelery.probes.readiness.period` | Period in seconds for performing the readiness probe. | integer | true | 60 |
| `gwcelery.probes.liveness.delay` | Delay in seconds before initiating the liveness probe. | integer | true | 150 |
| `gwcelery.probes.liveness.timeout` | Timeout in seconds for the liveness probe. | integer | true | 30 |
| `gwcelery.probes.liveness.period` | Period in seconds for performing the liveness probe. | integer | true | 60 |
| `gwcelery.storageClassName` | Storage class name for persistent storage. | string | true | standard |
| `gwcelery.ingress.enabled` | Enable an IngressRoute for Flower and Flask. | boolean | true | True |
| `gwcelery.ingress.host` | Host name for the IngressRoute. | string | true | gwcelery.default.svc.cluster.local |
| `gwcelery.brokerUrl` | Endpoint of an external Redis broker to receive messages (in the format redis://hostname:port). | string | false |  |
| `gwcelery.resultBackend` | Endpoint of an external Redis broker to send messages (in the format redis://hostname:port). | string | false |  |
| `gwcelery.ligoDatafindServer` | Endpoint of the LIGO Datafind server (in the format hostname:port) | string | true | datafind.ligo.uwm.edu:443 |
| `gwcelery.secrets.enabled` | Create a Secret containing the following entries:  netrc, auth.toml, x509up_u1000. | boolean | true | False |
| `gwcelery.secrets.netrc` | Contents of the _.netrc_ file for SCIMMA authentication. | string | false |  |
| `gwcelery.secrets.authtoml` | Contents of the _auth.toml_ file for SCIMMA authentication. | string | false |  |
| `gwcelery.secrets.x509up` | Contents of the client proxy certificate to connect to GraceDB (obtained with the _ligo-proxy-init_ command). | string | false |  |
| `gwcelery.celery.enabled` | Enable Celery workers. | boolean | true | True |
| `gwcelery.celery.concurrency` | Number of concurrent tasks for Celery workers. | integer | true | 8 |
| `gwcelery.celery.gwfProducer.enabled` | Enable GWF producer. | boolean | true | True |
| `gwcelery.celery.logLevel` | Logging level for Celery workers. | string | true | info |
| `gwcelery.celery.replicas` | Number of replicas for Celery workers. | integer | true | 1 |
| `gwcelery.celery.resources` | Resource requests and limits for Celery workers. | object | false | {} |
| `gwcelery.multiprocessing.enabled` | Enable Multiprocessing workers. | boolean | true | True |
| `gwcelery.multiprocessing.concurrency` | Number of concurrent tasks for Multiprocessing workers. | integer | true | 1 |
| `gwcelery.multiprocessing.logLevel` | Logging level for Multiprocessing workers. | string | true | info |
| `gwcelery.multiprocessing.replicas` | Number of replicas for Multiprocessing workers. | integer | true | 1 |
| `gwcelery.multiprocessing.resources` | Resource requests and limits for Multiprocessing workers. | object | false | {} |
| `gwcelery.multiprocessing.threads` | Number of OpenMP threads for Multiprocessing workers. | integer | true | 1 |
| `gwcelery.highmem.enabled` | Enable high memory workers. | boolean | true | True |
| `gwcelery.highmem.concurrency` | Number of concurrent tasks for high memory workers. | integer | true | 1 |
| `gwcelery.highmem.logLevel` | Logging level for high memory workers. | string | true | info |
| `gwcelery.highmem.replicas` | Number of replicas for high memory workers. | integer | true | 1 |
| `gwcelery.highmem.resources` | Resource requests and limits for high memory workers. | object | false | {} |
| `gwcelery.embright.enabled` | Enable Embright workers. | boolean | true | True |
| `gwcelery.embright.concurrency` | Number of concurrent tasks for Embright workers. | integer | true | 1 |
| `gwcelery.embright.logLevel` | Logging level for Embright workers. | string | true | info |
| `gwcelery.embright.replicas` | Number of replicas for Embright workers. | integer | true | 1 |
| `gwcelery.embright.resources` | Resource requests and limits for Embright workers. | object | false | {} |
| `gwcelery.exttrig.enabled` | Enable Exttrig workers. | boolean | true | False |
| `gwcelery.exttrig.logLevel` | Logging level for Exttrig workers. | string | true | info |
| `gwcelery.exttrig.resources` | Resource requests and limits for Exttrig workers. | object | false | {} |
| `gwcelery.openmp.enabled` | Enable OpenMP workers. | boolean | true | True |
| `gwcelery.openmp.concurrency` | Number of concurrent tasks for OpenMP workers. | integer | true | 2 |
| `gwcelery.openmp.logLevel` | Logging level for OpenMP workers. | string | true | info |
| `gwcelery.openmp.replicas` | Number of replicas for OpenMP workers. | integer | true | 1 |
| `gwcelery.openmp.resources` | Resource requests and limits for OpenMP workers. | object | false | {} |
| `gwcelery.openmp.threads` | Number of OpenMP threads for OpenMP workers. | integer | true | 4 |
| `gwcelery.flask.enabled` | Enable Flask service. | boolean | true | True |
| `gwcelery.flask.replicas` | Number of replicas for Flask service. | integer | true | 1 |
| `gwcelery.flask.resources.cpu` |  | number | false | 0.5 |
| `gwcelery.flask.service.type` | Service type for Flask. | string | true | ClusterIP |
| `gwcelery.flower.enabled` | Enable Flower for monitoring Celery. | boolean | true | True |
| `gwcelery.flower.replicas` | Number of replicas for Flower. | integer | true | 1 |
| `gwcelery.flower.resources.cpu` |  | number | false | 0.5 |
| `gwcelery.flower.service.type` | Service type for Flower. | string | true | ClusterIP |
| `gwcelery.superevent.enabled` | Enable Superevent workers. | boolean | true | True |
| `gwcelery.superevent.logLevel` | Logging level for Superevent workers. | string | true | info |
| `gwcelery.superevent.resources` | Resource requests and limits for Superevent workers. | object | false | {} |
| `gwcelery.voevent.enabled` | Enable Voevent workers. | boolean | true | True |
| `gwcelery.voevent.logLevel` | Logging level for Voevent workers. | string | true | info |
| `gwcelery.voevent.resources.cpu` |  | number | false | 0.5 |
| `gwcelery.kafka.enabled` | Enable Kafka workers. | boolean | true | True |
| `gwcelery.kafka.logLevel` | Logging level for Kafka workers. | string | true | info |
| `gwcelery.kafka.replicas` | Number of replicas for Kafka workers. | integer | true | 1 |
| `gwcelery.kafka.resources.cpu` | Number of CPUs for Kafka workers. | number | false | 0.5 |
| `gwcelery.kafka.resources.memory` | Amount of memory for Kafka workers.. | string | false | 2Gi |

## Subcharts

This chart depends on a [Redis subchart](https://artifacthub.io/packages/helm/bitnami/redis). The applied configuration to the Redis subchart is the following:
```
redis:
  redis:
    configmap: |-
      # Some GWCelery tasks transfer large payloads through Redis.
      # The default Redis client bandwidth limits are too small.
      client-output-buffer-limit normal 0 0 0
      client-output-buffer-limit slave 256mb 64mb 60
      client-output-buffer-limit pubsub 256mb 64mb 60

      # If worker nodes are only reachable on a specific network interface,
      # then make sure to bind any additional IP addresses here.
      # bind 127.0.0.1 10.0.0.1  # replace 10.0.0.1 with address on cluster network

      # Disable RDB snapshots.
      save ""

      # Enable appendonly snapshots.
      appendonly yes
      auto-aof-rewrite-percentage 95

  auth:
    enabled: false
    sentinel: false

  tls:
    enabled: false

  architecture: standalone

  master:
    service:
        type: ClusterIP
    disableCommands: []
    resources: 
      limits: 
        cpu: 0.1
        memory: 2Gi
    persistence:
      size: 20Gi

```


## Contributing

If you need to add new configuration keys, please do so by editing the file:

```
gwcelery/values-template.yaml
```

and add new keys according to the following schema:
```
key1:
  value: <default_value>
  required: [true,false]
  description: <short_descritpion_string>
  mytype: ["integer", "string", "boolean","number", "array", "object"]
key2:
  mytype: "object"
  subkey1:
    value: <default_value>
    required: [true,false]
    description: <short_descritpion_string>
    mytype: ["integer", "string", "boolean","number", "array", "object"]
  subkey2:
    value: <default_value>
    required: [true,false]
    description: <short_descritpion_string>
    mytype: ["integer", "string", "boolean","number", "array", "object"]
```

Only for values that are not required, insert an _if_ statement in the Jinja templates. 

In order to produce the `values.yaml` and `values.schema.json` corresponding to the template file, run the following script:
```
pushd gwcelery
./make-schema-and-values.sh 
```
In order to produce an updated `README.md` file including the new keys, run:
```
popd
./create-readme.sh
``` 


## CI pipeline

This repository's CI pipeline builds and uploads the Helm chart to the the package registry whenever a new tag is created.
