import sys

def clean_yaml(input_yaml, output_yaml):
    with open(input_yaml, 'r') as file:
        lines = file.readlines()

    cleaned_lines = []  # Holds the cleaned lines
    indent_stack = []   # Stack to manage indentation levels

    for line in lines:
        stripped_line = line.strip()

        # Preserve comments and empty lines
        if stripped_line.startswith("#") or not stripped_line:
            cleaned_lines.append(line)
            continue

        # Check for key-value pairs
        if ':' in stripped_line:
            key, value = map(str.strip, stripped_line.split(':', 1))

            # Handle special keys
            if key in ["required", "description", "mytype"]:
                continue  # Skip these keys

            if key == "value":
                # Add the value to the last key, preserving indentation
                if indent_stack: 
                    last_key_index = indent_stack[-1]
                    # Append the value inline to the last non-value key
                    cleaned_lines[last_key_index] = (
                        cleaned_lines[last_key_index].rstrip() + f' {value.strip()}\n'
                    )
                continue  # Skip adding the value line

            # For regular keys, create the key line with no value
            current_indent = len(line) - len(stripped_line)
            cleaned_lines.append(f"{' ' * (current_indent-1)}{key}:\n")

            # Push the current index onto the stack
            indent_stack.append(len(cleaned_lines) - 1)

        else:
            # If line is not recognized, just keep it
            cleaned_lines.append(line)

            # Check for indentation level change
            current_indent = len(line) - len(stripped_line)
            if current_indent < len(cleaned_lines[indent_stack[-1]].rstrip()):
                # Pop from stack if going back up in hierarchy
                indent_stack.pop()
    
    # Write the cleaned data back to the specified output file
    with open(output_yaml, 'w') as outfile:
        outfile.writelines(cleaned_lines)
        

if __name__ == "__main__":
    if len(sys.argv) != 3:
        print("Usage: python clean_yaml.py <input_file> <output_file>")
    else:
        input_file = sys.argv[1]
        output_file = sys.argv[2]
        clean_yaml(input_file, output_file)
        print("Cleaned "+input_file+" and saved to "+output_file) 
