{{- define "gwcelery.celery.hostAliases" -}}
{{- if .Values.gwcelery.hostAlias.hostname -}}
{{- if .Values.gwcelery.hostAlias.ip -}}
hostAliases:
  - ip: {{ .Values.gwcelery.hostAlias.ip }}
    hostnames:
      - {{ .Values.gwcelery.hostAlias.hostname }}
{{- end -}}
{{- end -}}
{{- end -}}

{{- define "gwcelery.celery.configHash" -}}
checksum/config: {{ include (print $.Template.BasePath "/gwcelery-config.yaml") . | sha256sum }}
checksum/probe: {{ include (print $.Template.BasePath "/probe-cm.yaml") . | sha256sum }}
{{- if .Values.gwcelery.secrets.enabled }}
checksum/secret: {{ include (print $.Template.BasePath "/secrets.yaml") . | sha256sum }}
{{- end }}
{{- end -}}

{{- define "gwcelery.celery.probes" -}}
readinessProbe:
  exec:
    command:
      - /home/gwcelery/probe.py
  initialDelaySeconds: {{ .Values.gwcelery.probes.readiness.delay }}
  periodSeconds: {{ .Values.gwcelery.probes.readiness.period }}
  timeoutSeconds: {{ .Values.gwcelery.probes.readiness.timeout }}
livenessProbe:
  exec:
    command:
      - /home/gwcelery/probe.py
  initialDelaySeconds: {{ .Values.gwcelery.probes.liveness.delay }}
  periodSeconds: {{ .Values.gwcelery.probes.liveness.period }}
  timeoutSeconds: {{ .Values.gwcelery.probes.liveness.timeout }}
{{- end -}}

{{- define "gwcelery.celery.base.initContainers" -}}
- name: copy-secrets
  #image: alpine
  image: {{ include "gwcelery.image" . }} 
  imagePullPolicy: {{ .Values.gwcelery.image.pullPolicy }}
  command: ["/bin/sh","-c"]
  args: 
    - cp /tmp/secrets/auth.toml /tmp/secrets-copy/auth.toml ;
      chmod 600 /tmp/secrets-copy/auth.toml ;
      cp /tmp/secrets/netrc /tmp/secrets-copy/netrc ;
      chmod 600 /tmp/secrets-copy/netrc ;
      cp /tmp/secrets/kafka_credential_map /tmp/secrets-copy/kafka_credential_map.json ;
      chmod 600 /tmp/secrets-copy/kafka_credential_map.json ;
      cp /tmp/secrets/x509up_u1000 /tmp/secrets-copy/x509up_u1000 ;
      chmod 600 /tmp/secrets-copy/x509up_u1000 ;
      cat $(python -m requests.certs) /tmp/ca.crt > /tmp/cabundle/cacerts.pem
  volumeMounts:
    - name: secrets
      mountPath: /tmp/secrets
    - name: secrets-copy
      mountPath: /tmp/secrets-copy
    - name: gracedb-ca
      mountPath: /tmp/ca.crt
      subPath: ca.crt
    - name: cabundle
      mountPath: /tmp/cabundle
{{- end -}}

{{- define "gwcelery.celery.base.env" -}}
{{- if .Values.gwcelery.celeryConfig }}
- name: CELERY_CONFIG_MODULE 
  value: 'gwcelery.conf.helm-k8s'
{{- else }}
- name: CELERY_CONFIG_MODULE 
  value: {{ .Values.gwcelery.celeryConfigModule }}
{{- end }}
- name: BROKER_USE_SSL
  value: 'False'
- name: CELERY_BROKER_URL
  {{- if .Values.gwcelery.brokerUrl }}
  value: {{ .Values.gwcelery.brokerUrl }} 
  {{- else }}
  value: {{ printf "redis://%s-master:6379" (include "common.names.fullname" .Subcharts.redis) }}
  {{- end }}
- name: CELERY_RESULT_BACKEND
  {{- if .Values.gwcelery.resultBackend }}
  value: {{ .Values.gwcelery.resultBackend }}
  {{- else }}
  value: {{ printf "redis://%s-master:6379" (include "common.names.fullname" .Subcharts.redis) }}
  {{- end }}
{{- if .Values.gwcelery.gracedb.caSecret }}
- name: REQUESTS_CA_BUNDLE
  value: /home/gwcelery/cacerts.pem
{{- end }}
- name: GRACEDB_HOSTNAME
  value: {{ .Values.gwcelery.gracedb.hostname }}
- name: IGWN_HOSTNAME
  value: {{ .Values.gwcelery.igwnHostname }}
- name: KAFKA_HOSTNAME
  value: {{ .Values.gwcelery.kafkaHostname }}
- name: LIGO_DATAFIND_SERVER
  value: {{ .Values.gwcelery.ligoDatafindServer }}
{{- end -}}

{{- define  "gwcelery.celery.base.volumeMounts" -}}
- name: secrets-copy
  mountPath: /home/gwcelery/.netrc
  subPath: netrc
- name: xdg-config
  mountPath: /home/gwcelery/.config
- name: secrets-copy
  mountPath: /home/gwcelery/.config/hop/auth.toml
  subPath: auth.toml
- name: secrets-copy
  mountPath: /home/gwcelery/.config/gwcelery/kafka_credential_map.json
  subPath: kafka_credential_map.json
- name: secrets-copy
  mountPath: /tmp/x509up_u1000
  subPath: x509up_u1000
- name: secrets-copy
  mountPath: /tmp/secrets-copy
- name: secrets
  mountPath: /tmp/secrets
- name: probe
  mountPath: /home/gwcelery/probe.py
  subPath: probe.py
{{- if .Values.gwcelery.celeryConfig }}
- name: config
  mountPath: /opt/venv/lib/python3.11/site-packages/gwcelery/conf
  subPath: helm-k8s.py
{{- end }}
{{- if .Values.gwcelery.gracedb.caSecret }}
- name: cabundle
  mountPath: /home/gwcelery/cacerts.pem
  subPath: cacerts.pem
{{- end }}
{{- end -}}

{{- define "gwcelery.celery.base.volumes" -}}
- name: secrets                                 
  secret:                                                  
    defaultMode: 0640
    secretName: {{ include "gwcelery.fullname" . }}-secrets 
- name: secrets-copy
  emptyDir: {}
- name: xdg-config
  emptyDir: {}
- name: probe
  configMap:
    name: {{ include "gwcelery.fullname" . }}-probe
    defaultMode: 0770
{{- if .Values.gwcelery.celeryConfig  }}
- name: config
  configMap:
    defaultMode: 0640
    name: "gwcelery-config"
{{- end }}
{{- if .Values.gwcelery.gracedb.caSecret }}
- name: cabundle
  emptyDir: {}
- name: gracedb-ca
  secret:
    secretName: {{ .Values.gwcelery.gracedb.caSecret }}
{{- end }}
{{- end -}}
